INTEGRATION_ARTIFACT_BUCKET = "integration_artifact_s3_bucket"
ENVIRONMENT = "environment"
ARTIFACT_MANAGER = "integration_artifact_manager"
PROTRACTOR_TEST_DIR = "protractor_test_dir"
INTEGRATION_TARGET_URL = "integration_target_url"
TAVERN_TEST_DIR = "tavern_test_dir"
DEFAULT_TAVERN_TEST_DIR = "src/integrationtest/tavern"
PROMOTE_ARTIFACT = "promote"
ROLE = "role"
APPLICATION = "application"
APPLICATION_GROUP = "application_group"
